@@ -3,7 +3,7 @@ Define the Figure class that handles all plotting.
 """
 import base64
 import os
-import warnings
+from pathlib import Path
 from tempfile import TemporaryDirectory
 
 try:
@@ -59,8 +59,9 @@ class Figure:
     Examples
     --------
 
-    >>> fig = Figure()
-    >>> fig.basemap(region=[0, 360, -90, 90], projection="W7i", frame=True)
+    >>> import pygmt
+    >>> fig = pygmt.Figure()
+    >>> fig.basemap(region=[0, 360, -90, 90], projection="W15c", frame=True)
     >>> fig.savefig("my-figure.png")
     >>> # Make sure the figure file is generated and clean it up
     >>> import os
@@ -69,10 +70,11 @@ class Figure:
     >>> os.remove("my-figure.png")
 
     The plot region can be specified through ISO country codes (for example,
-    ``'JP'`` for Japan):
+    ``"JP"`` for Japan):
 
-    >>> fig = Figure()
-    >>> fig.basemap(region="JP", projection="M3i", frame=True)
+    >>> import pygmt
+    >>> fig = pygmt.Figure()
+    >>> fig.basemap(region="JP", projection="M7c", frame=True)
     >>> # The fig.region attribute shows the WESN bounding box for the figure
     >>> print(", ".join(f"{i:.2f}" for i in fig.region))
     122.94, 145.82, 20.53, 45.52
@@ -104,7 +106,7 @@ class Figure:
         # Passing format '-' tells pygmt.end to not produce any files.
         fmt = "-"
         with Session() as lib:
-            lib.call_module("figure", f"{self._name} {fmt}")
+            lib.call_module(module="figure", args=f"{self._name} {fmt}")
 
     def _preprocess(self, **kwargs):
         """
@@ -130,6 +132,7 @@ class Figure:
         C="gs_option",
         E="dpi",
         F="prefix",
+        G="gs_path",
         I="resize",
         N="bb_style",
         T="fmt",
@@ -137,16 +140,16 @@ class Figure:
         V="verbose",
     )
     @kwargs_to_strings()
-    def psconvert(self, icc_gray=False, **kwargs):
+    def psconvert(self, **kwargs):
         r"""
         Convert [E]PS file(s) to other formats.
 
         Converts one or more PostScript files to other formats (BMP, EPS, JPEG,
-        PDF, PNG, PPM, SVG, TIFF) using GhostScript.
+        PDF, PNG, PPM, TIFF) using Ghostscript.
 
         If no input files are given, will convert the current active figure
-        (see :func:`pygmt.figure`). In this case, an output name must be given
-        using parameter *prefix*.
+        (see :class:`pygmt.Figure`). In this case, an output name must be given
+        using parameter ``prefix``.
 
         Full option list at :gmt-docs:`psconvert.html`
 
@@ -163,11 +166,13 @@ class Figure:
             creating very small images where the difference of one pixel
             might matter. If ``verbose`` is used we also report the
             dimensions of the final illustration.
+        gs_path : str
+            Full path to the Ghostscript executable.
         gs_option : str
             Specify a single, custom option that will be passed on to
-            GhostScript as is.
+            Ghostscript as is.
         dpi : int
-            Set raster resolution in dpi. Default = 720 for PDF, 300 for
+            Set raster resolution in dpi. Default is 720 for PDF, 300 for
             others.
         prefix : str
             Force the output file name. By default output names are constructed
@@ -176,7 +181,7 @@ class Figure:
             but without extension. Extension is still determined automatically.
         resize : str
             [**+m**\ *margins*][**+s**\ [**m**]\ *width*\
-            [/\ *height*]][**+S**\ *scale*] ].
+            [/\ *height*]][**+S**\ *scale*].
             Adjust the BoundingBox and HiResBoundingBox by scaling and/or
             adding margins. Append **+m** to specify extra margins to extend
             the bounding box. Give either one (uniform), two (x and y) or four
@@ -198,9 +203,9 @@ class Figure:
             towards black (100%) [no fading, 0]. Append **+g**\ *paint* to
             paint the BoundingBox behind the illustration and append **+p**\
             [*pen*] to draw the BoundingBox outline (append a pen or accept
-            the default pen of 0.25p,black). Note: If both **+g** and **+f**
-            are used then we use paint as the fade color instead of black.
-            Append **+i** to enforce gray-shades by using ICC profiles.
+            the default pen of 0.25p,black). **Note**: If both **+g** and
+            **+f** are used then we use paint as the fade color instead of
+            black. Append **+i** to enforce gray-shades by using ICC profiles.
         anti_aliasing : str
             [**g**\|\ **p**\|\ **t**\][**1**\|\ **2**\|\ **4**].
             Set the anti-aliasing options for **g**\ raphics or **t**\ ext.
@@ -211,41 +216,40 @@ class Figure:
             **E** means EPS with PageSize command, **f** means PDF, **F** means
             multi-page PDF, **j** means JPEG, **g** means PNG, **G** means
             transparent PNG (untouched regions are transparent), **m** means
-            PPM, **s** means SVG, and **t** means TIFF [default is JPEG]. To
+            PPM, and **t** means TIFF [Default is JPEG]. To
             **b**\|\ **j**\|\ **g**\|\ **t**\ , optionally append **+m** in
             order to get a monochrome (grayscale) image. The EPS format can be
             combined with any of the other formats. For example, **ef** creates
             both an EPS and a PDF file. Using **F** creates a multi-page PDF
             file from the list of input PS or PDF files. It requires the
             ``prefix`` parameter.
-        {V}
+        {verbose}
         """
         kwargs = self._preprocess(**kwargs)
         # Default cropping the figure to True
-        if "A" not in kwargs:
+        if kwargs.get("A") is None:
             kwargs["A"] = ""
-
-        if icc_gray:
-            msg = (
-                "The 'icc_gray' parameter has been deprecated since v0.6.0"
-                " and will be removed in v0.8.0."
-            )
-            warnings.warn(msg, category=FutureWarning, stacklevel=2)
-            if "N" not in kwargs:
-                kwargs["N"] = "+i"
-            else:
-                kwargs["N"] += "+i"
-
         # Manually handle prefix -F argument so spaces aren't converted to \040
         # by build_arg_string function. For more information, see
         # https://github.com/GenericMappingTools/pygmt/pull/1487
-        try:
-            prefix_arg = f'-F"{kwargs.pop("F")}"'
-        except KeyError as err:
-            raise GMTInvalidInput("The 'prefix' must be specified.") from err
+        prefix = kwargs.pop("F", None)
+        if prefix in ["", None, False, True]:
+            raise GMTInvalidInput(
+                "The 'prefix' parameter must be specified with a valid value."
+            )
+        prefix_arg = f'-F"{prefix}"'
+
+        # check if the parent directory exists
+        prefix_path = Path(prefix).parent
+        if not prefix_path.exists():
+            raise FileNotFoundError(
+                f"No such directory: '{prefix_path}', please create it first."
+            )
 
         with Session() as lib:
-            lib.call_module("psconvert", f"{prefix_arg} {build_arg_string(kwargs)}")
+            lib.call_module(
+                module="psconvert", args=f"{prefix_arg} {build_arg_string(kwargs)}"
+            )
 
     def savefig(
         self, fname, transparent=False, crop=True, anti_alias=True, show=False, **kwargs
@@ -284,6 +288,10 @@ class Figure:
         dpi : int
             Set raster resolution in dpi. Default is 720 for PDF, 300 for
             others.
+        **kwargs : dict
+            Additional keyword arguments passed to
+            :meth:`pygmt.Figure.psconvert`. Valid parameters are ``gs_path``,
+            ``gs_option``, ``resize``, ``bb_style``, and ``verbose``.
         """
         # All supported formats
         fmts = dict(png="g", pdf="f", jpg="j", bmp="b", eps="e", tif="t", kml="g")
@@ -314,7 +322,7 @@ class Figure:
         if show:
             launch_external_viewer(fname)
 
-    def show(self, dpi=300, width=500, method=None, waiting=0.5):
+    def show(self, dpi=300, width=500, method=None, waiting=0.5, **kwargs):
         """
         Display a preview of the figure.
 
@@ -329,7 +337,7 @@ class Figure:
         for the current figure. Parameters ``dpi`` and ``width`` can be used
         to control the resolution and dimension of the figure in the notebook.
 
-        Note: The external viewer can be disabled by setting the
+        **Note**: The external viewer can be disabled by setting the
         PYGMT_USE_EXTERNAL_DISPLAY environment variable to **false**.
         This is useful when running unit tests and building the documentation
         in consoles without a Graphical User Interface.
@@ -349,13 +357,17 @@ class Figure:
         method : str
             How the current figure will be displayed. Options are
 
-            - **external**: PDF preview in an external program [default]
-            - **notebook**: PNG preview [default in Jupyter notebooks]
+            - **external**: PDF preview in an external program [Default]
+            - **notebook**: PNG preview [Default in Jupyter notebooks]
             - **none**: Disable image preview
         waiting : float
             Suspend the execution of the current process for a given number of
             seconds after launching an external viewer.
             Only works if ``method="external"``.
+        **kwargs : dict
+            Additional keyword arguments passed to
+            :meth:`pygmt.Figure.psconvert`. Valid parameters are ``gs_path``,
+            ``gs_option``, ``resize``, ``bb_style``, and ``verbose``.
         """
         # Module level variable to know which figures had their show method
         # called. Needed for the sphinx-gallery scraper.
@@ -382,20 +394,24 @@ class Figure:
                         "or run the script in a Jupyter notebook."
                     )
                 )
-            png = self._preview(fmt="png", dpi=dpi, anti_alias=True, as_bytes=True)
+            png = self._preview(
+                fmt="png", dpi=dpi, anti_alias=True, as_bytes=True, **kwargs
+            )
             IPython.display.display(IPython.display.Image(data=png, width=width))
 
         if method == "external":
-            pdf = self._preview(fmt="pdf", dpi=dpi, anti_alias=False, as_bytes=False)
+            pdf = self._preview(
+                fmt="pdf", dpi=dpi, anti_alias=False, as_bytes=False, **kwargs
+            )
             launch_external_viewer(pdf, waiting=waiting)
 
     def shift_origin(self, xshift=None, yshift=None):
         """
         Shift plot origin in x and/or y directions.
 
-        This method shifts plot origin relative to the current origin by
-        (*xshift*, *yshift*) and optionally append the length unit (**c**,
-        **i**, or **p**).
+        This method shifts the plot origin relative to the current origin
+        by (*xshift*, *yshift*). Optionally, append the length unit (**c**,
+        **i**, or **p**). Default unit if not given is **c** for centimeter.
 
         Prepend **a** to shift the origin back to the original position after
         plotting, prepend **c** to center the plot on the center of the paper
@@ -421,7 +437,7 @@ class Figure:
             args.append(f"-Y{yshift}")
 
         with Session() as lib:
-            lib.call_module("plot", " ".join(args))
+            lib.call_module(module="plot", args=" ".join(args))
 
     def _preview(self, fmt, dpi, as_bytes=False, **kwargs):
         """
@@ -492,6 +508,7 @@ class Figure:
         set_panel,
         solar,
         subplot,
+        ternary,
         text,
         velo,
         wiggle,
@@ -507,8 +524,8 @@ def set_display(method=None):
     method : str or None
         The method to display an image. Choose from:
 
-        - **external**: PDF preview in an external program [default]
-        - **notebook**: PNG preview [default in Jupyter notebooks]
+        - **external**: PDF preview in an external program [Default]
+        - **notebook**: PNG preview [Default in Jupyter notebooks]
         - **none**: Disable image preview
     """
     if method in ["notebook", "external", "none"]:
