@@ -23,7 +23,7 @@ class grdhisteq:  # pylint: disable=invalid-name
     r"""
     Perform histogram equalization for a grid.
 
-    Two common use cases of :meth:`pygmt.grdhisteq` are to find data values
+    Two common use cases of :class:`pygmt.grdhisteq` are to find data values
     that divide a grid into patches of equal area
     (:meth:`pygmt.grdhisteq.compute_bins`) or to write a grid with
     statistics based on some kind of cumulative distribution function
@@ -39,7 +39,7 @@ class grdhisteq:  # pylint: disable=invalid-name
     provide a list of data values that divide the data range into divisions
     which have an equal area in the image [Default is 16 if ``divisions`` is
     not set]. The :class:`pandas.DataFrame` or ASCII file output can be used to
-    make a colormap with :meth:`pygmt.makecpt` and an image with
+    make a colormap with :func:`pygmt.makecpt` and an image with
     :meth:`pygmt.Figure.grdimage` that has all levels of gray occurring
     equally.
 
@@ -89,9 +89,9 @@ class grdhisteq:  # pylint: disable=invalid-name
         divisions : int
             Set the number of divisions of the data range [Default is 16].
 
-        {R}
-        {V}
-        {h}
+        {region}
+        {verbose}
+        {header}
 
         Returns
         -------
@@ -106,7 +106,7 @@ class grdhisteq:  # pylint: disable=invalid-name
 
         See Also
         -------
-        :meth:`pygmt.grd2cpt`
+        :func:`pygmt.grd2cpt`
         """
 
         with Session() as lib:
@@ -176,8 +176,8 @@ class grdhisteq:  # pylint: disable=invalid-name
             range.
         quadratic: bool
             Perform quadratic equalization [Default is linear].
-        {R}
-        {V}
+        {region}
+        {verbose}
 
         Returns
         -------
@@ -201,7 +201,7 @@ class grdhisteq:  # pylint: disable=invalid-name
 
         See Also
         -------
-        :meth:`pygmt.grd2cpt`
+        :func:`pygmt.grd2cpt`
 
         Note
         ----
@@ -254,7 +254,7 @@ class grdhisteq:  # pylint: disable=invalid-name
         can provide a list of data values that divide the data range into
         divisions which have an equal area in the image [Default is 16 if
         ``divisions`` is not set]. The :class:`pandas.DataFrame` or ASCII file
-        output can be used to make a colormap with :meth:`pygmt.makecpt` and an
+        output can be used to make a colormap with :func:`pygmt.makecpt` and an
         image with :meth:`pygmt.Figure.grdimage` that has all levels of gray
         occurring equally.
 
@@ -278,9 +278,9 @@ class grdhisteq:  # pylint: disable=invalid-name
             Set the number of divisions of the data range.
         quadratic : bool
             Perform quadratic equalization [Default is linear].
-        {R}
-        {V}
-        {h}
+        {region}
+        {verbose}
+        {header}
 
         Returns
         -------
@@ -306,15 +306,15 @@ class grdhisteq:  # pylint: disable=invalid-name
         >>> print(bins)
                 start    stop
         bin_id
-        0       179.0   397.5
-        1       397.5   475.5
-        2       475.5   573.5
-        3       573.5   710.5
-        4       710.5  2103.0
+        0       170.0   389.0
+        1       389.0   470.5
+        2       470.5   571.0
+        3       571.0   705.0
+        4       705.0  2275.5
 
         See Also
         -------
-        :meth:`pygmt.grd2cpt`
+        :func:`pygmt.grd2cpt`
 
         Note
         ----
