@@ -12,6 +12,8 @@ from pygmt.helpers import (
     use_alias,
 )
 
+__doctest_skip__ = ["grdimage"]
+
 
 @fmt_docstring
 @use_alias(
@@ -29,8 +31,6 @@ from pygmt.helpers import (
     R="region",
     U="timestamp",
     V="verbose",
-    X="xshift",
-    Y="yshift",
     n="interpolation",
     c="panel",
     f="coltypes",
@@ -49,12 +49,12 @@ def grdimage(self, grid, **kwargs):
     added by providing a file with intensities in the (-1,+1) range or
     instructions to derive intensities from the input data grid. Values outside
     this range will be clipped. Such intensity files can be created from the
-    grid using :meth:`pygmt.grdgradient` and, optionally, modified by
-    ``grdmath`` or ``grdhisteq``. If GMT is built with GDAL support, ``grid``
-    can be an image file (geo-referenced or not). In this case the image can
-    optionally be illuminated with the file provided via the ``shading``
-    parameter. Here, if image has no coordinates then those of the intensity
-    file will be used.
+    grid using :func:`pygmt.grdgradient` and, optionally, modified by
+    :gmt-docs:`grdmath.html` or :class:`pygmt.grdhisteq`. If GMT is built
+    with GDAL support, ``grid`` can be an image file (geo-referenced or not).
+    In this case the image can optionally be illuminated with the file
+    provided via the ``shading`` parameter. Here, if image has no coordinates
+    then those of the intensity file will be used.
 
     When using map projections, the grid is first resampled on a new
     rectangular grid with the same dimensions. Higher resolution images can
@@ -95,12 +95,12 @@ def grdimage(self, grid, **kwargs):
         drivers. Append a **+c**\ *args* string where *args* is a list
         of one or more concatenated number of GDAL **-co** arguments. For
         example, to write a GeoPDF with the TerraGo format use
-        ``=PDF+cGEO_ENCODING=OGC_BP``. Notes: (1) If a tiff file (.tif) is
-        selected then we will write a GeoTiff image if the GMT projection
-        syntax translates into a PROJ syntax, otherwise a plain tiff file
-        is produced. (2) Any vector elements will be lost.
-    {B}
-    {CPT}
+        ``=PDF+cGEO_ENCODING=OGC_BP``. **Notes**: (1) If a tiff file (.tif)
+        is selected then we will write a GeoTiff image if the GMT
+        projection syntax translates into a PROJ syntax, otherwise a plain
+        tiff file is produced. (2) Any vector elements will be lost.
+    {frame}
+    {cmap}
     img_in : str
         [**r**].
         GMT will automatically detect standard image files (Geotiff, TIFF,
@@ -108,9 +108,9 @@ def grdimage(self, grid, **kwargs):
         image formats you may need to explicitly set ``img_in``, which
         specifies that the grid is in fact an image file to be read via
         GDAL. Append **r** to assign the region specified by ``region``
-        to the image. For example, if you have used ``region='d'`` then the
-        image will be assigned a global domain. This mode allows you to
-        project a raw image (an image without referencing coordinates).
+        to the image. For example, if you have used ``region="d"`` then
+        the image will be assigned a global domain. This mode allows you
+        to project a raw image (an image without referencing coordinates).
     dpi : int
         [**i**\|\ *dpi*].
         Sets the resolution of the projected grid that will be created if a
@@ -131,16 +131,17 @@ def grdimage(self, grid, **kwargs):
         Give the name of a grid file or a DataArray with intensities in the
         (-1,+1) range, or a constant intensity to apply everywhere (affects the
         ambient light). Alternatively, derive an intensity grid from the input
-        data grid via a call to :meth:`pygmt.grdgradient`; append
+        data grid via a call to :func:`pygmt.grdgradient`; append
         **+a**\ *azimuth*, **+n**\ *args*, and **+m**\ *ambient* to specify
-        azimuth, intensity, and ambient arguments for that method, or just give
-        **+d** to select the default arguments (``+a-45+nt1+m0``). If you want
-        a more specific intensity scenario then run :meth:`pygmt.grdgradient`
-        separately first. If we should derive intensities from another file
-        than grid, specify the file with suitable modifiers [Default is no
-        illumination]. Note: If the input data is an *image* then an
-        *intensfile* or constant *intensity* must be provided.
-    {J}
+        azimuth, intensity, and ambient arguments for that function, or just
+        give **+d** to select the default arguments (``+a-45+nt1+m0``). If you
+        want a more specific intensity scenario then run
+        :func:`pygmt.grdgradient` separately first. If we should derive
+        intensities from another file than grid, specify the file with
+        suitable modifiers [Default is no illumination]. **Note**: If the
+        input data is an *image* then an *intensfile* or constant *intensity*
+        must be provided.
+    {projection}
     monochrome : bool
         Force conversion to monochrome image using the (television) YIQ
         transformation. Cannot be used with ``nan_transparent``.
@@ -151,15 +152,27 @@ def grdimage(self, grid, **kwargs):
         Make grid nodes with z = NaN transparent, using the color-masking
         feature in PostScript Level 3 (the PS device must support PS Level
         3).
-    {R}
-    {V}
-    {XY}
-    {c}
-    {f}
-    {n}
-    {p}
-    {t}
-    {x}
+    {region}
+    {verbose}
+    {panel}
+    {coltypes}
+    {interpolation}
+    {perspective}
+    {transparency}
+    {cores}
+
+    Example
+    -------
+    >>> import pygmt
+    >>> # load the 30 arc-minutes grid with "gridline" registration
+    >>> grid = pygmt.datasets.load_earth_relief("30m", registration="gridline")
+    >>> # create a new plot with pygmt.Figure()
+    >>> fig = pygmt.Figure()
+    >>> # pass in the grid and set the CPT to "geo"
+    >>> # set the projection to Mollweide and the size to 10 cm
+    >>> fig.grdimage(grid=grid, cmap="geo", projection="W10c", frame="ag")
+    >>> # show the plot
+    >>> fig.show()
     """
     kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
     with Session() as lib:
@@ -167,7 +180,9 @@ def grdimage(self, grid, **kwargs):
         with contextlib.ExitStack() as stack:
             # shading using an xr.DataArray
             if kwargs.get("I") is not None and data_kind(kwargs["I"]) == "grid":
-                shading_context = lib.virtualfile_from_grid(kwargs["I"])
+                shading_context = lib.virtualfile_from_data(
+                    check_kind="raster", data=kwargs["I"]
+                )
                 kwargs["I"] = stack.enter_context(shading_context)
 
             fname = stack.enter_context(file_context)
