@@ -35,7 +35,7 @@ def grdproject(grid, **kwargs):
     r"""
     Change projection of gridded data between geographical and rectangular.
 
-    This module will project a geographical gridded data set onto a
+    This method will project a geographical gridded data set onto a
     rectangular grid. If ``inverse`` is ``True``, it will project a
     rectangular coordinate system to a geographic system. To obtain the value
     at each new node, its location is inversely projected back onto the input
@@ -44,11 +44,13 @@ def grdproject(grid, **kwargs):
     avoided by also forward projecting the input grid nodes. If two or more
     nodes are projected onto the same new node, their average will dominate in
     the calculation of the new node value. Interpolation and aliasing is
-    controlled with the ``interpolation`` option. The new node spacing may be
-    determined in one of several ways by specifying the grid spacing, number
-    of nodes, or resolution. Nodes not constrained by input data are set to
-    NaN. The ``region`` parameter can be used to select a map region larger or
-    smaller than that implied by the extent of the grid file.
+    controlled with the ``interpolation`` parameter. The new node spacing may
+    be determined in one of several ways by specifying the grid spacing,
+    number of nodes, or resolution. Nodes not constrained by input data are
+    set to NaN. The ``region`` parameter can be used to select a map region
+    large or smaller than that implied by the extent of the grid file.
+
+    Full option list at :gmt-docs:`grdproject.html`
 
     {aliases}
 
@@ -62,8 +64,8 @@ def grdproject(grid, **kwargs):
     inverse : bool
         When set to ``True`` transforms grid from rectangular to
         geographical [Default is False].
-    {J}
-    {R}
+    {projection}
+    {region}
     center : str or list
         [*dx*, *dy*].
         Let projected coordinates be relative to projection center [Default
@@ -71,7 +73,7 @@ def grdproject(grid, **kwargs):
         projected units to be added (or subtracted when ``inverse`` is set) to
         (from) the projected coordinates, such as false eastings and
         northings for particular projection zones [0/0].
-    {I}
+    {spacing}
     dpi : int
         Set the resolution for the new grid in dots per inch.
     scaling : str
@@ -84,9 +86,9 @@ def grdproject(grid, **kwargs):
     unit : str
         Append **c**, **i**, or **p** to indicate that cm, inch, or point
         should be the projected measure unit. Cannot be used with ``scaling``.
-    {V}
-    {n}
-    {r}
+    {verbose}
+    {interpolation}
+    {registration}
 
     Returns
     -------
@@ -110,16 +112,16 @@ def grdproject(grid, **kwargs):
     >>> # to "rectangular"
     >>> new_grid = pygmt.grdproject(grid=grid, projection="M10c", inverse=True)
     """
-    if "J" not in kwargs:
+    if kwargs.get("J") is None:
         raise GMTInvalidInput("The projection must be specified.")
     with GMTTempFile(suffix=".nc") as tmpfile:
         with Session() as lib:
             file_context = lib.virtualfile_from_data(check_kind="raster", data=grid)
             with file_context as infile:
-                if "G" not in kwargs:  # if outgrid is unset, output to tempfile
-                    kwargs.update({"G": tmpfile.name})
-                outgrid = kwargs["G"]
-                arg_str = " ".join([infile, build_arg_string(kwargs)])
-                lib.call_module("grdproject", arg_str)
+                if (outgrid := kwargs.get("G")) is None:
+                    kwargs["G"] = outgrid = tmpfile.name  # output to tmpfile
+                lib.call_module(
+                    module="grdproject", args=build_arg_string(kwargs, infile=infile)
+                )
 
         return load_dataarray(outgrid) if outgrid == tmpfile.name else None
