@@ -6,7 +6,6 @@ from pygmt.clib import Session
 from pygmt.helpers import (
     GMTTempFile,
     build_arg_string,
-    deprecate_parameter,
     fmt_docstring,
     kwargs_to_strings,
     use_alias,
@@ -14,7 +13,6 @@ from pygmt.helpers import (
 
 
 @fmt_docstring
-@deprecate_parameter("table", "data", "v0.5.0", remove_version="v0.7.0")
 @use_alias(
     C="per_column",
     I="spacing",
@@ -50,7 +48,7 @@ def info(data, **kwargs):
     Parameters
     ----------
     data : str or {table-like}
-        Pass in either a file name to an ASCII data table, a 1D/2D
+        Pass in either a file name to an ASCII data table, a 1-D/2-D
         {table-classes}.
     per_column : bool
         Report the min/max values per column in separate columns.
@@ -66,11 +64,11 @@ def info(data, **kwargs):
         Report the min/max of the first (0'th) column to the nearest multiple
         of dz and output this in the form ``[zmin, zmax, dz]``.
 
-    {V}
-    {a}
-    {i}
-    {f}
-    {r}
+    {verbose}
+    {aspatial}
+    {incols}
+    {coltypes}
+    {registration}
 
     Returns
     -------
@@ -85,13 +83,13 @@ def info(data, **kwargs):
         file_context = lib.virtualfile_from_data(check_kind="vector", data=data)
         with GMTTempFile() as tmpfile:
             with file_context as fname:
-                arg_str = " ".join(
-                    [fname, build_arg_string(kwargs), "->" + tmpfile.name]
+                lib.call_module(
+                    module="info",
+                    args=build_arg_string(kwargs, infile=fname, outfile=tmpfile.name),
                 )
-                lib.call_module("info", arg_str)
             result = tmpfile.read()
 
-        if any(arg in kwargs for arg in ["C", "I", "T"]):
+        if any(kwargs.get(arg) is not None for arg in ["C", "I", "T"]):
             # Converts certain output types into a numpy array
             # instead of a raw string that is less useful.
             if result.startswith(("-R", "-T")):  # e.g. -R0/1/2/3 or -T0/9/1
