@@ -6,6 +6,7 @@ from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import (
     build_arg_string,
     data_kind,
+    deprecate_parameter,
     fmt_docstring,
     is_nonstr_iter,
     kwargs_to_strings,
@@ -15,6 +16,7 @@ from pygmt.src.which import which
 
 
 @fmt_docstring
+@deprecate_parameter("color", "fill", "v0.8.0", remove_version="v0.12.0")
 @use_alias(
     A="straight_line",
     B="frame",
@@ -22,7 +24,7 @@ from pygmt.src.which import which
     D="offset",
     E="error_bar",
     F="connection",
-    G="color",
+    G="fill",
     I="intensity",
     J="projection",
     L="close",
@@ -32,8 +34,6 @@ from pygmt.src.which import which
     U="timestamp",
     V="verbose",
     W="pen",
-    X="xshift",
-    Y="yshift",
     Z="zvalue",
     a="aspatial",
     b="binary",
@@ -59,7 +59,7 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
 
     Must provide either ``data`` or ``x``/``y``.
 
-    If providing data through ``x``/``y``, ``color`` can be a 1d array that
+    If providing data through ``x``/``y``, ``fill`` can be a 1-D array that
     will be mapped to a colormap.
 
     If a symbol is selected and no symbol size given, then plot will
@@ -68,9 +68,9 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
     symbol code (see ``style`` below) must be present as last column in the
     input. If ``style`` is not used, a line connecting the data points will
     be drawn instead. To explicitly close polygons, use ``close``. Select a
-    fill with ``color``. If ``color`` is set, ``pen`` will control whether the
-    polygon outline is drawn or not. If a symbol is selected, ``color`` and
-    ``pen`` determines the fill and outline/no outline, respectively.
+    fill with ``fill``. If ``fill`` is set, ``pen`` will control whether the
+    polygon outline is drawn or not. If a symbol is selected, ``fill`` and
+    ``pen`` determine the fill and outline/no outline, respectively.
 
     Full option list at :gmt-docs:`plot.html`
 
@@ -79,27 +79,28 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
     Parameters
     ----------
     data : str or {table-like}
-        Pass in either a file name to an ASCII data table, a 2D
+        Pass in either a file name to an ASCII data table, a 2-D
         {table-classes}.
-        Use parameter ``incols`` to choose which columns are x, y, color, and
+        Use parameter ``incols`` to choose which columns are x, y, fill, and
         size, respectively.
-    x/y : float or 1d arrays
+    x/y : float or 1-D arrays
         The x and y coordinates, or arrays of x and y coordinates of the
         data points
-    size : 1d array
+    size : 1-D array
         The size of the data points in units specified using ``style``.
         Only valid if using ``x``/``y``.
-    direction : list of two 1d arrays
-        If plotting vectors (using ``style='V'`` or ``style='v'``), then
-        should be a list of two 1d arrays with the vector directions. These
+    direction : list of two 1-D arrays
+        If plotting vectors (using ``style="V"`` or ``style="v"``), then
+        should be a list of two 1-D arrays with the vector directions. These
         can be angle and length, azimuth and length, or x and y components,
         depending on the style options chosen.
-    {J}
-    {R}
+    {projection}
+    {region}
     straight_line : bool or str
         [**m**\|\ **p**\|\ **x**\|\ **y**].
         By default, geographic line segments are drawn as great circle
-        arcs. To draw them as straight lines, use ``straight_line``.
+        arcs. To draw them as straight lines, use
+        ``straight_line=True``.
         Alternatively, add **m** to draw the line by first following a
         meridian, then a parallel. Or append **p** to start following a
         parallel, then a meridian. (This can be practical to draw a line
@@ -107,17 +108,17 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
         simply connected, unless you append **x** or **y** to draw
         stair-case curves that whose first move is along *x* or *y*,
         respectively.
-    {B}
-    {CPT}
+    {frame}
+    {cmap}
     offset : str
         *dx*/*dy*.
         Offset the plot symbol or line locations by the given amounts
         *dx/dy* [Default is no offset]. If *dy* is not given it is set
         equal to *dx*.
     error_bar : bool or str
-        [**+b**\|\ **d**\|\ **D**][**+xl**\|\ **r**\|\ *x0*]\
-        [**+yl**\|\ **r**\|\ *y0*][**+p**\ *pen*].
-        Draw symmetrical error bars. Full documentation is at
+        [**x**\|\ **y**\|\ **X**\|\ **Y**][**+a**\|\ **A**]\
+        [**+cl**\|\ **f**][**+n**][**+w**\ *cap*][**+p**\ *pen*].
+        Draw error bars. Full documentation is at
         :gmt-docs:`plot.html#e`.
     connection : str
         [**c**\|\ **n**\|\ **r**]\
@@ -146,21 +147,21 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
           incoming segment [Default].
         - **r** : Same as **s**, but the group reference point is reset
           after each record to the previous point (this method is only
-          available with the ``connection='r'`` scheme).
+          available with the ``connection="r"`` scheme).
 
         Instead of the codes **a**\|\ **f**\|\ **s**\|\ **r** you may append
         the coordinates of a *refpoint* which will serve as a fixed external
         reference point for all groups.
-    {G}
-        *color* can be a 1d array, but it is only valid if using ``x``/``y``
+    {fill}
+        *fill* can be a 1-D array, but it is only valid if using ``x``/``y``
         and ``cmap=True`` is also required.
-    intensity : float or bool or 1d array
+    intensity : float or bool or 1-D array
         Provide an *intensity* value (nominally in the -1 to +1 range) to
         modulate the fill color by simulating illumination. If using
         ``intensity=True``, we will instead read *intensity* from the first
         data column after the symbol parameters (if given). *intensity* can
-        also be a 1d array to set varying intensity for symbols, but it is only
-        valid for ``x``/``y`` pairs.
+        also be a 1-D array to set varying intensity for symbols, but it is
+        only valid for ``x``/``y`` pairs.
     close : str
         [**+b**\|\ **d**\|\ **D**][**+xl**\|\ **r**\|\ *x0*]\
         [**+yl**\|\ **r**\|\ *y0*][**+p**\ *pen*].
@@ -181,34 +182,34 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
     style : str
         Plot symbols (including vectors, pie slices, fronts, decorated or
         quoted lines).
-    {W}
-    {U}
-    {V}
-    {XY}
+    {pen}
+    {timestamp}
+    {verbose}
     zvalue : str
         *value*\|\ *file*.
         Instead of specifying a symbol or polygon fill and outline color
-        via ``color`` and ``pen``, give both a *value* via ``zvalue`` and a
+        via ``fill`` and ``pen``, give both a *value* via ``zvalue`` and a
         color lookup table via ``cmap``.  Alternatively, give the name of a
         *file* with one z-value (read from the last column) for each
         polygon in the input data. To apply it to the fill color, use
-        ``color='+z'``. To apply it to the pen color, append **+z** to
+        ``fill="+z"``. To apply it to the pen color, append **+z** to
         ``pen``.
-    {a}
-    {b}
-    {c}
-    {d}
-    {e}
-    {f}
-    {g}
-    {h}
-    {i}
-    {l}
-    {p}
-    {t}
-        *transparency* can also be a 1d array to set varying transparency
-        for symbols, but this option is only valid if using x/y.
-    {w}
+    {aspatial}
+    {binary}
+    {panel}
+    {nodata}
+    {find}
+    {coltypes}
+    {gap}
+    {header}
+    {incols}
+    {label}
+    {perspective}
+    {transparency}
+        ``transparency`` can also be a 1-D array to set varying
+        transparency for symbols, but this option is only valid if using
+        ``x``/``y``.
+    {wrap}
     """
     # pylint: disable=too-many-locals
     kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
@@ -237,7 +238,7 @@ def plot(self, data=None, x=None, y=None, size=None, direction=None, **kwargs):
     if kwargs.get("G") is not None and is_nonstr_iter(kwargs["G"]):
         if kind != "vectors":
             raise GMTInvalidInput(
-                "Can't use arrays for color if data is matrix or file."
+                "Can't use arrays for fill if data is matrix or file."
             )
         extra_arrays.append(kwargs["G"])
         del kwargs["G"]
