@@ -5,8 +5,8 @@ from pygmt.clib import Session
 from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import (
     build_arg_string,
-    check_data_input_order,
     data_kind,
+    deprecate_parameter,
     fmt_docstring,
     is_nonstr_iter,
     kwargs_to_strings,
@@ -16,13 +16,13 @@ from pygmt.src.which import which
 
 
 @fmt_docstring
-@check_data_input_order("v0.5.0", remove_version="v0.7.0")
+@deprecate_parameter("color", "fill", "v0.8.0", remove_version="v0.12.0")
 @use_alias(
     A="straight_line",
     B="frame",
     C="cmap",
     D="offset",
-    G="color",
+    G="fill",
     I="intensity",
     J="projection",
     Jz="zscale",
@@ -34,8 +34,6 @@ from pygmt.src.which import which
     S="style",
     V="verbose",
     W="pen",
-    X="xshift",
-    Y="yshift",
     Z="zvalue",
     a="aspatial",
     b="binary",
@@ -58,13 +56,13 @@ def plot3d(
     r"""
     Plot lines, polygons, and symbols in 3-D.
 
-    Takes a matrix, (x,y,z) triplets, or a file name as input and plots
+    Takes a matrix, (x, y, z) triplets, or a file name as input and plots
     lines, polygons, or symbols at those locations in 3-D.
 
-    Must provide either ``data`` or ``x``/``y``/``z``.
+    Must provide either ``data`` or ``x``, ``y``, and ``z``.
 
-    If providing data through ``x/y/z``, ``color`` can be a 1d array
-    that will be mapped to a colormap.
+    If providing data through ``x``, ``y``, and ``z``, ``fill`` can be a
+    1-D array that will be mapped to a colormap.
 
     If a symbol is selected and no symbol size given, then plot3d will
     interpret the fourth column of the input data as symbol size. Symbols
@@ -72,35 +70,35 @@ def plot3d(
     symbol code (see ``style`` below) must be present as last column in the
     input. If ``style`` is not used, a line connecting the data points will
     be drawn instead. To explicitly close polygons, use ``close``. Select a
-    fill with ``color``. If ``color`` is set, ``pen`` will control whether the
-    polygon outline is drawn or not. If a symbol is selected, ``color`` and
-    ``pen`` determines the fill and outline/no outline, respectively.
+    fill with ``fill``. If ``fill`` is set, ``pen`` will control whether the
+    polygon outline is drawn or not. If a symbol is selected, ``fill`` and
+    ``pen`` determine the fill and outline/no outline, respectively.
 
-    Full parameter list at :gmt-docs:`plot3d.html`
+    Full option list at :gmt-docs:`plot3d.html`
 
     {aliases}
 
     Parameters
     ----------
     data : str or {table-like}
-        Either a data file name, a 2d {table-classes}.
+        Either a data file name, a 2-D {table-classes}.
         Optionally, use parameter ``incols`` to specify which columns are x, y,
-        z, color, and size, respectively.
-    x/y/z : float or 1d arrays
+        z, fill, and size, respectively.
+    x/y/z : float or 1-D arrays
         The x, y, and z coordinates, or arrays of x, y and z coordinates of
         the data points
-    size : 1d array
+    size : 1-D array
         The size of the data points in units specified in ``style``.
         Only valid if using ``x``/``y``/``z``.
-    direction : list of two 1d arrays
-        If plotting vectors (using ``style='V'`` or ``style='v'``), then
-        should be a list of two 1d arrays with the vector directions. These
+    direction : list of two 1-D arrays
+        If plotting vectors (using ``style="V"`` or ``style="v"``), then
+        should be a list of two 1-D arrays with the vector directions. These
         can be angle and length, azimuth and length, or x and y components,
         depending on the style options chosen.
-    {J}
+    {projection}
     zscale/zsize : float or str
         Set z-axis scaling or z-axis size.
-    {R}
+    {region}
     straight_line : bool or str
         [**m**\|\ **p**\|\ **x**\|\ **y**].
         By default, geographic line segments are drawn as great circle
@@ -113,22 +111,22 @@ def plot3d(
         stair-case curves that whose first move is along *x* or *y*,
         respectively. **Note**: The ``straight_line`` parameter requires
         constant *z*-coordinates.
-    {B}
-    {CPT}
+    {frame}
+    {cmap}
     offset : str
         *dx*/*dy*\ [/*dz*].
         Offset the plot symbol or line locations by the given amounts
         *dx*/*dy*\ [/*dz*] [Default is no offset].
-    {G}
-        *color* can be a 1d array, but it is only valid if using ``x``/``y``
+    {fill}
+        *fill* can be a 1-D array, but it is only valid if using ``x``/``y``
         and ``cmap=True`` is also required.
-    intensity : float or bool or 1d array
+    intensity : float or bool or 1-D array
         Provide an *intensity* value (nominally in the -1 to +1 range) to
         modulate the fill color by simulating illumination. If using
         ``intensity=True``, we will instead read *intensity* from the first
         data column after the symbol parameters (if given). *intensity* can
-        also be a 1d array to set varying intensity for symbols, but it is only
-        valid for ``x``/``y``/``z``.
+        also be a 1-D array to set varying intensity for symbols, but it is
+        only valid for ``x``/``y``/``z``.
 
     close : str
         [**+b**\|\ **d**\|\ **D**][**+xl**\|\ **r**\|\ *x0*]\
@@ -153,34 +151,34 @@ def plot3d(
         the foreground are plotted after items in the background.
     style : str
         Plot symbols. Full documentation is at :gmt-docs:`plot3d.html#s`.
-    {U}
-    {V}
-    {W}
-    {XY}
+    {timestamp}
+    {verbose}
+    {pen}
     zvalue : str
         *value*\|\ *file*.
         Instead of specifying a symbol or polygon fill and outline color
-        via ``color`` and ``pen``, give both a *value* via **zvalue** and a
+        via ``fill`` and ``pen``, give both a *value* via **zvalue** and a
         color lookup table via ``cmap``.  Alternatively, give the name of a
         *file* with one z-value (read from the last column) for each
         polygon in the input data. To apply it to the fill color, use
-        ``color='+z'``. To apply it to the pen color, append **+z** to
+        ``fill="+z"``. To apply it to the pen color, append **+z** to
         ``pen``.
-    {a}
-    {b}
-    {c}
-    {d}
-    {e}
-    {f}
-    {g}
-    {h}
-    {i}
-    {l}
-    {p}
-    {t}
-        *transparency* can also be a 1d array to set varying transparency
-        for symbols, but this option is only valid if using x/y/z.
-    {w}
+    {aspatial}
+    {binary}
+    {panel}
+    {nodata}
+    {find}
+    {coltypes}
+    {gap}
+    {header}
+    {incols}
+    {label}
+    {perspective}
+    {transparency}
+        ``transparency`` can also be a 1-D array to set varying
+        transparency for symbols, but this option is only valid if using
+        ``x``/``y``/``z``.
+    {wrap}
     """
     # pylint: disable=too-many-locals
     kwargs = self._preprocess(**kwargs)  # pylint: disable=protected-access
@@ -188,15 +186,15 @@ def plot3d(
     kind = data_kind(data, x, y, z)
 
     extra_arrays = []
-    if "S" in kwargs and kwargs["S"][0] in "vV" and direction is not None:
+    if kwargs.get("S") is not None and kwargs["S"][0] in "vV" and direction is not None:
         extra_arrays.extend(direction)
     elif (
-        "S" not in kwargs
+        kwargs.get("S") is None
         and kind == "geojson"
         and data.geom_type.isin(["Point", "MultiPoint"]).all()
     ):  # checking if the geometry of a geoDataFrame is Point or MultiPoint
         kwargs["S"] = "u0.2c"
-    elif "S" not in kwargs and kind == "file" and data.endswith(".gmt"):
+    elif kwargs.get("S") is None and kind == "file" and str(data).endswith(".gmt"):
         # checking that the data is a file path to set default style
         try:
             with open(which(data), mode="r", encoding="utf8") as file:
@@ -206,10 +204,10 @@ def plot3d(
                 kwargs["S"] = "u0.2c"
         except FileNotFoundError:
             pass
-    if "G" in kwargs and is_nonstr_iter(kwargs["G"]):
+    if kwargs.get("G") is not None and is_nonstr_iter(kwargs["G"]):
         if kind != "vectors":
             raise GMTInvalidInput(
-                "Can't use arrays for color if data is matrix or file."
+                "Can't use arrays for fill if data is matrix or file."
             )
         extra_arrays.append(kwargs["G"])
         del kwargs["G"]
@@ -221,7 +219,7 @@ def plot3d(
         extra_arrays.append(size)
 
     for flag in ["I", "t"]:
-        if flag in kwargs and is_nonstr_iter(kwargs[flag]):
+        if kwargs.get(flag) is not None and is_nonstr_iter(kwargs[flag]):
             if kind != "vectors":
                 raise GMTInvalidInput(
                     f"Can't use arrays for {plot3d.aliases[flag]} if data is matrix or file."
@@ -242,5 +240,6 @@ def plot3d(
         )
 
         with file_context as fname:
-            arg_str = " ".join([fname, build_arg_string(kwargs)])
-            lib.call_module("plot3d", arg_str)
+            lib.call_module(
+                module="plot3d", args=build_arg_string(kwargs, infile=fname)
+            )
