@@ -3,16 +3,16 @@ Tests Figure.basemap.
 """
 import pytest
 from pygmt import Figure
-from pygmt.exceptions import GMTInvalidInput
 
 
+@pytest.mark.mpl_image_compare
 def test_basemap_required_args():
     """
-    Figure.basemap fails when not given required arguments.
+    Automatically set `frame=True` when required arguments are not given.
     """
     fig = Figure()
-    with pytest.raises(GMTInvalidInput):
-        fig.basemap(region=[10, 70, -3, 8], projection="X8c/6c")
+    fig.basemap(region=[10, 70, -3, 8], projection="X8c/6c")
+    return fig
 
 
 @pytest.mark.mpl_image_compare
@@ -48,7 +48,7 @@ def test_basemap_power_axis():
     fig.basemap(
         region=[0, 100, 0, 5000],
         projection="x1p0.5/-0.001",
-        frame=['x1p+l"Crustal age"', "y500+lDepth"],
+        frame=["x1p+lCrustal age", "y500+lDepth"],
     )
     return fig
 
