@@ -4,6 +4,7 @@ Test the behavior of the Figure class.
 Doesn't include the plotting commands which have their own test files.
 """
 import os
+from pathlib import Path
 
 try:
     import IPython
@@ -89,6 +90,17 @@ def test_figure_savefig_exists():
         os.remove(fname)
 
 
+def test_figure_savefig_directory_nonexists():
+    """
+    Make sure that Figure.savefig() raises a FileNotFoundError when the parent
+    directory doesn't exist.
+    """
+    fig = Figure()
+    fig.basemap(region="10/70/-300/800", projection="X3i/5i", frame="af")
+    with pytest.raises(FileNotFoundError, match="No such directory:"):
+        fig.savefig("a-nonexist-directory/test_figure_savefig_directory_nonexists.png")
+
+
 def test_figure_savefig_unknown_extension():
     """
     Check that an error is raised when an unknown extension is passed.
@@ -138,8 +150,9 @@ def test_figure_savefig_filename_with_spaces():
     fig = Figure()
     fig.basemap(region=[0, 1, 0, 1], projection="X1c/1c", frame=True)
     with GMTTempFile(prefix="pygmt-filename with spaces", suffix=".png") as imgfile:
-        fig.savefig(imgfile.name)
-        assert os.path.exists(imgfile.name)
+        fig.savefig(fname=imgfile.name)
+        assert r"\040" not in os.path.abspath(imgfile.name)
+        assert Path(imgfile.name).stat().st_size > 0
 
 
 def test_figure_savefig():
@@ -251,3 +264,24 @@ def test_figure_set_display_invalid():
     """
     with pytest.raises(GMTInvalidInput):
         set_display(method="invalid")
+
+
+def test_figure_deprecated_xshift_yshift():
+    """
+    Check if deprecation of parameters X/Y/xshift/yshift work correctly if
+    used.
+    """
+    fig = Figure()
+    fig.basemap(region=[0, 1, 0, 1], projection="X1c/1c", frame=True)
+    with pytest.warns(expected_warning=SyntaxWarning) as record:
+        fig.plot(x=1, y=1, style="c3c", xshift="3c")
+        assert len(record) == 1  # check that only one warning was raised
+    with pytest.warns(expected_warning=SyntaxWarning) as record:
+        fig.plot(x=1, y=1, style="c3c", X="3c")
+        assert len(record) == 1  # check that only one warning was raised
+    with pytest.warns(expected_warning=SyntaxWarning) as record:
+        fig.plot(x=1, y=1, style="c3c", yshift="3c")
+        assert len(record) == 1  # check that only one warning was raised
+    with pytest.warns(expected_warning=SyntaxWarning) as record:
+        fig.plot(x=1, y=1, style="c3c", Y="3c")
+        assert len(record) == 1  # check that only one warning was raised
