@@ -5,9 +5,9 @@ import os
 
 import pytest
 from pygmt import Figure, grd2cpt
-from pygmt.datasets import load_earth_relief
 from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import GMTTempFile
+from pygmt.helpers.testing import load_static_earth_relief
 
 
 @pytest.fixture(scope="module", name="grid")
@@ -15,7 +15,7 @@ def fixture_grid():
     """
     Load the grid data from the sample earth_relief file.
     """
-    return load_earth_relief()
+    return load_static_earth_relief()
 
 
 @pytest.mark.mpl_image_compare
@@ -27,7 +27,7 @@ def test_grd2cpt(grid):
     fig = Figure()
     fig.basemap(frame="a", projection="W0/15c", region="d")
     grd2cpt(grid=grid)
-    fig.colorbar(frame="a2000")
+    fig.colorbar(frame="a")
     return fig
 
 
