@@ -1,7 +1,7 @@
 """
 Tests for grdproject.
 """
-import os
+from pathlib import Path
 
 import pytest
 import xarray as xr
@@ -20,7 +20,7 @@ def fixture_grid():
 
 
 @pytest.fixture(scope="module", name="expected_grid")
-def fixture_grid_result():
+def fixture_expected_grid():
     """
     Load the expected grdproject grid result.
     """
@@ -53,7 +53,7 @@ def test_grdproject_file_out(grid, expected_grid):
             region=[-53, -51, -20, -17],
         )
         assert result is None  # return value is None
-        assert os.path.exists(path=tmpfile.name)  # check that outgrid exists
+        assert Path(tmpfile.name).stat().st_size > 0  # check that outgrid exists
         temp_grid = load_dataarray(tmpfile.name)
         xr.testing.assert_allclose(a=temp_grid, b=expected_grid)
 
