@@ -2,9 +2,10 @@
 Tests grdview.
 """
 import pytest
-from pygmt import Figure, grdcut, which
+from pygmt import Figure, grdcut
 from pygmt.exceptions import GMTInvalidInput
 from pygmt.helpers import GMTTempFile, data_kind
+from pygmt.helpers.testing import load_static_earth_relief
 
 
 @pytest.fixture(scope="module", name="region")
@@ -12,25 +13,33 @@ def fixture_region():
     """
     Test region as lonmin, lonmax, latmin, latmax.
     """
-    return (-116, -109, -47, -44)
+    return [-55, -50, -18, -12]
+
+
+@pytest.fixture(scope="module", name="grid")
+def fixture_grid():
+    """
+    Load the grid data from the static_earth_relief file.
+    """
+    return load_static_earth_relief()
 
 
 @pytest.fixture(scope="module", name="gridfile")
-def fixture_gridfile(region):
+def fixture_gridfile(grid, region):
     """
     Load the NetCDF grid file from the sample earth_relief file.
     """
     with GMTTempFile(suffix=".nc") as tmpfile:
-        grdcut(grid="@earth_relief_01d_g", region=region, outgrid=tmpfile.name)
+        grdcut(grid=grid, region=region, outgrid=tmpfile.name)
         yield tmpfile.name
 
 
 @pytest.fixture(scope="module", name="xrgrid")
-def fixture_xrgrid(region):
+def fixture_xrgrid(grid, region):
     """
     Load the xarray.DataArray grid from the sample earth_relief file.
     """
-    return grdcut(grid="@earth_relief_01d_g", region=region)
+    return grdcut(grid=grid, region=region)
 
 
 @pytest.mark.mpl_image_compare
@@ -43,18 +52,6 @@ def test_grdview_grid_dataarray(xrgrid):
     return fig
 
 
-@pytest.mark.mpl_image_compare
-def test_grdview_grid_file_with_region_subset(region):
-    """
-    Run grdview by passing in a grid filename, and cropping it to a region.
-    """
-    gridfile = which("@earth_relief_01d_g", download="a")
-
-    fig = Figure()
-    fig.grdview(grid=gridfile, region=region)
-    return fig
-
-
 def test_grdview_wrong_kind_of_grid(xrgrid):
     """
     Run grdview using grid input that is not an xarray.DataArray or file.
@@ -129,7 +126,7 @@ def test_grdview_with_cmap_for_surface_monochrome_plot(xrgrid):
 def test_grdview_with_cmap_for_perspective_surface_plot(xrgrid):
     """
     Run grdview by passing in a grid and setting a colormap for producing a
-    surface plot with a 3D perspective viewpoint.
+    surface plot with a 3-D perspective viewpoint.
     """
     fig = Figure()
     fig.grdview(
@@ -142,10 +139,10 @@ def test_grdview_with_cmap_for_perspective_surface_plot(xrgrid):
 def test_grdview_on_a_plane(xrgrid):
     """
     Run grdview by passing in a grid and plotting it on a z-plane, while
-    setting a 3D perspective viewpoint.
+    setting a 3-D perspective viewpoint.
     """
     fig = Figure()
-    fig.grdview(grid=xrgrid, plane=-4000, perspective=[225, 30], zscale=0.005)
+    fig.grdview(grid=xrgrid, plane=100, perspective=[225, 30], zscale=0.005)
     return fig
 
 
@@ -153,10 +150,10 @@ def test_grdview_on_a_plane(xrgrid):
 def test_grdview_on_a_plane_with_colored_frontal_facade(xrgrid):
     """
     Run grdview by passing in a grid and plotting it on a z-plane whose frontal
-    facade is colored gray, while setting a 3D perspective viewpoint.
+    facade is colored gray, while setting a 3-D perspective viewpoint.
     """
     fig = Figure()
-    fig.grdview(grid=xrgrid, plane="-4000+ggray", perspective=[225, 30], zscale=0.005)
+    fig.grdview(grid=xrgrid, plane="100+ggray", perspective=[225, 30], zscale=0.005)
     return fig
 
 
@@ -209,7 +206,7 @@ def test_grdview_on_a_plane_styled_with_facadepen(xrgrid):
     fig = Figure()
     fig.grdview(
         grid=xrgrid,
-        plane=-4000,
+        plane=100,
         perspective=[225, 30],
         zscale=0.005,
         facadepen="0.5p,blue,dash",
@@ -217,6 +214,10 @@ def test_grdview_on_a_plane_styled_with_facadepen(xrgrid):
     return fig
 
 
+@pytest.mark.xfail(
+    reason="Generated images are different from the baseline images on three platforms. "
+    "See https://github.com/GenericMappingTools/pygmt/issues/2062#issuecomment-1220680290"
+)
 @pytest.mark.mpl_image_compare
 def test_grdview_drapegrid_dataarray(xrgrid):
     """
