@@ -1,7 +1,7 @@
 """
 Tests for xyz2grd.
 """
-import os
+from pathlib import Path
 
 import numpy as np
 import pytest
@@ -21,7 +21,7 @@ def fixture_ship_data():
 
 
 @pytest.fixture(scope="module", name="expected_grid")
-def fixture_grid_result():
+def fixture_expected_grid():
     """
     Load the expected xyz2grd grid result.
     """
@@ -42,7 +42,7 @@ def fixture_grid_result():
 @pytest.mark.parametrize("array_func", [np.array, xr.Dataset])
 def test_xyz2grd_input_array(array_func, ship_data, expected_grid):
     """
-    Run xyz2grd by passing in an xarray datset or numpy array.
+    Run xyz2grd by passing in an xarray dataset or numpy array.
     """
     output = xyz2grd(data=array_func(ship_data), spacing=5, region=[245, 255, 20, 30])
     assert isinstance(output, xr.DataArray)
@@ -63,7 +63,7 @@ def test_xyz2grd_input_array_file_out(ship_data, expected_grid):
             outgrid=tmpfile.name,
         )
         assert result is None  # return value is None
-        assert os.path.exists(path=tmpfile.name)
+        assert Path(tmpfile.name).stat().st_size > 0
         temp_grid = load_dataarray(tmpfile.name)
         xr.testing.assert_allclose(a=temp_grid, b=expected_grid)
 
